@@ -1,11 +1,12 @@
 package PGObject::Type::DateTime;
 
-use 5.008;
+use 5.010;
 use Carp;
 use strict;
 use warnings;
 use base qw(DateTime);
 use DateTime::TimeZone;
+use PGObject;
 
 =head1 NAME
 
@@ -13,11 +14,11 @@ PGObject::Type::DateTime - DateTime Wrappers for PGObject
 
 =head1 VERSION
 
-Version 1.0.5
+Version 2.0.1
 
 =cut
 
-our $VERSION = '1.0.5';
+our $VERSION = 2.000001;
 our $default_tz = DateTime::TimeZone->new(name => 'UTC');
 
 
@@ -29,6 +30,12 @@ Now all Datetime, Timestamp, and TimestampTZ types are returned
 returned as datetime objects.  Date and time modules may require subclasses
 to serialize properly to the database.
 
+=head1 ONGOING WORK IN 2.X
+
+During the 2.x series we expect to work on better NULL support.  Right now this
+is all delegated to clild classes, but there are likely to be cases where we
+add this to our library directly.
+
 =head1 DESCRIPTION
 
 This module provides a basic wrapper around DateTime to allow PGObject-framework
@@ -68,10 +75,16 @@ sub register {
     $types = ['date', 'time', 'timestamp', 'timestamptz'] 
            unless defined $types and @$types;
     for my $type (@$types){
-        my $ret = 
-            PGObject->register_type(registry => $registry, pg_type => $type,
+        if ($PGObject::VERSION =~ /^1\./) { # 1.x
+            my $ret = 
+                PGObject->register_type(registry => $registry, pg_type => $type,
                                   perl_class => $self);
-        return $ret unless $ret;
+        } else { # higher than 1.x
+            require PGObject::Type::Registry;
+            PGObject::Type::Registry->register_type(
+                 registry => $registry, dbtype => $type, apptype => $self
+            );
+        }
     }
     return 1;
 }
@@ -311,7 +324,7 @@ L<http://search.cpan.org/dist/PGObject-Type-DateTime/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013 Chris Travers.
+Copyright 2013-2017 Chris Travers.
 
 This program is released under the following license: BSD
 
